@@ -2,19 +2,24 @@
 ## Convert from SPS to STS format
 ## ==============================
 
-SPS_to_STS <- function(seqdata,type,stsep) {
+SPS_to_STS <- function(seqdata, spsformat) {
 
 	nbseq <- seqdim(seqdata)[1]
 	trans <- matrix("", nrow=nbseq, ncol=1)
+
+	if (spsformat$xfix!="") 
+		xfix <- paste("[",spsformat$xfix,"]", sep="")
+	else xfix=""
+	sdsep <- spsformat$sdsep
 	
 	for (i in 1:nbseq) {
-		tmpseq <- strsplit(seqdata[i],split=stsep)[[1]]
-		for (s in 1:length(tmpseq)) {
-			if (type==1) sps <- strsplit(gsub("[()]","",tmpseq[s]),split=",")[[1]]
-			else sps <- strsplit(tmpseq[s],split="/")[[1]]
+		tmpseq <- na.omit(seqdata[i,])
 
-			seq <- sps[[1]]
-			dur <- as.integer(sps[[2]])
+		for (s in 1:length(tmpseq)) {
+			sps <- strsplit(gsub(xfix,"",tmpseq[s]), split=sdsep)[[1]]
+	
+			seq <- sps[1]
+			dur <- as.integer(sps[2])
 
 			if (s==1) trans[i] <- paste(trans[i],seq,sep="") 
 			else trans[i] <- paste(trans[i],seq,sep="-")
@@ -24,5 +29,7 @@ SPS_to_STS <- function(seqdata,type,stsep) {
 		}
 	}
 
+	trans <- seqdecomp(trans)
+
 	return(trans)
 }
